@@ -1,27 +1,23 @@
-"""perform trasformations on env-variables sets."""
+"""perform transformations on env-variables sets."""
 from dataclasses import replace
 from fnmatch import fnmatch
 
-from dotenv.main import dotenv_values
 import toolz
 
 from chenv import fs
+from chenv import settings
 from chenv.models.output import Output
 
 
 def ignore(variables: dict) -> dict:
     """Filter variable keys by unix patterns in `.envignore`."""
-    ignores = set(fs.load_lines(".envignore"))
-    return {
-        key: value
-        for key, value in variables.items()
-        if not any(fnmatch(key, ignored) for ignored in ignores)
-    }
+    ignores = set(fs.load_lines(settings.ENVIGNORE))
+    return {key: value for key, value in variables.items() if not any(fnmatch(key, ignored) for ignored in ignores)}
 
 
 def merge(variables: dict) -> str:
     """Merge / override variable set with env-variables defined in `.envmerge`."""
-    overriders = dotenv_values(".envmerge")
+    overriders = fs.load(path=settings.ENVMERGE)
     return toolz.merge(variables, overriders)
 
 
